@@ -4,6 +4,10 @@ MIN_REF_COVERAGE = -5.0
 MAX_REF_SPREAD = 1.0
 NULL_LOG2_COVERAGE = -20.0
 
+# Thresholds used in GC-content masking of bad bins at 'fix' step
+GC_MIN_FRACTION = 0.3
+GC_MAX_FRACTION = 0.7
+
 # Fragment size for paired-end reads
 INSERT_SIZE = 250
 
