@@ -54,7 +54,7 @@ def correlate_cnv_expression(cnv_fname, expression_fname):
         "kendall_t": tau,
         "pearson_r": r.values,
         "spearman_r": rho,
-    }, index=cnv_table.index).clip_lower(0).fillna(0)
+    }, index=cnv_table.index).clip(lower=0).fillna(0)
     result.insert(0, 'hugo_gene',
             cnv_table['Hugo_Symbol'].fillna('').values)
     return result
