@@ -13,40 +13,48 @@ from .subtract import subtract
 from .subdivide import subdivide
 
 
-class GenomicArray(object):
+class GenomicArray:
     """An array of genomic intervals. Base class for genomic data structures.
 
     Can represent most BED-like tabular formats with arbitrary additional
     columns.
     """
+
     _required_columns = ("chromosome", "start", "end")
     _required_dtypes = (str, int, int)
 
     def __init__(self, data_table, meta_dict=None):
         # Validation
-        if (data_table is None or
-            (isinstance(data_table, (list, tuple)) and not len(data_table)) or
-            (isinstance(data_table, pd.DataFrame) and not len(data_table.columns))
-           ):
+        if (
+            data_table is None
+            or (isinstance(data_table, (list, tuple)) and not len(data_table))
+            or (isinstance(data_table, pd.DataFrame) and not len(data_table.columns))
+        ):
             data_table = self._make_blank()
         else:
             if not isinstance(data_table, pd.DataFrame):
                 # Rarely if ever needed -- prefer from_rows, from_columns, etc.
                 data_table = pd.DataFrame(data_table)
             if not all(c in data_table.columns for c in self._required_columns):
-                raise ValueError("data table must have at least columns %r; "
-                                 "got %r" % (self._required_columns,
-                                             tuple(data_table.columns)))
+                raise ValueError(
+                    "data table must have at least columns "
+                    + f"{self._required_columns!r}; got {tuple(data_table.columns)!r}"
+                )
             # Ensure columns are the right type
             # (in case they've been automatically converted to the wrong type,
             # e.g. chromosome names as integers; genome coordinates as floats)
             if len(data_table):
+
                 def ok_dtype(col, dt):
                     return isinstance(data_table[col].iat[0], dt)
+
             else:
+
                 def ok_dtype(col, dt):
                     return data_table[col].dtype == np.dtype(dt)
-            recast_cols = {col: dtype
+
+            recast_cols = {
+                col: dtype
                 for col, dtype in zip(self._required_columns, self._required_dtypes)
                 if not ok_dtype(col, dtype)
             }
@@ -54,9 +62,7 @@ class GenomicArray(object):
                 data_table = data_table.astype(recast_cols)
 
         self.data = data_table
-        self.meta = (dict(meta_dict)
-                     if meta_dict is not None and len(meta_dict)
-                     else {})
+        self.meta = dict(meta_dict) if meta_dict is not None and len(meta_dict) else {}
 
     @classmethod
     def _make_blank(cls):
@@ -66,7 +72,7 @@ class GenomicArray(object):
             arr = np.zeros(0, dtype=spec)
             return pd.DataFrame(arr)
         except TypeError as exc:
-            raise TypeError("{}: {}".format(exc, spec))
+            raise TypeError(r"{exc}: {spec}") from exc
 
     @classmethod
     def from_columns(cls, columns, meta_dict=None):
@@ -96,20 +102,20 @@ class GenomicArray(object):
         return self.__class__(dframe, self.meta.copy())
 
     def as_series(self, arraylike):
+        """Coerce `arraylike` to a Series with this instance's index."""
         return pd.Series(arraylike, index=self.data.index)
 
     def as_rows(self, rows):
         """Wrap the given rows in this instance's metadata."""
         try:
-            out = self.from_rows(rows,
-                                 columns=self.data.columns,
-                                 meta_dict=self.meta)
-        except AssertionError:
+            out = self.from_rows(rows, columns=self.data.columns, meta_dict=self.meta)
+        except AssertionError as exc:
             columns = self.data.columns.tolist()
             firstrow = next(iter(rows))
-            raise RuntimeError("Passed %d columns %r, but "
-                               "%d elements in first row: %s",
-                               len(columns), columns, len(firstrow), firstrow)
+            raise RuntimeError(
+                f"Passed {len(columns)} columns {columns!r}, but "
+                f"{len(firstrow)} elements in first row: {firstrow}"
+            ) from exc
         return out
 
     # Container behaviour
@@ -118,8 +124,7 @@ class GenomicArray(object):
         return bool(len(self.data))
 
     def __eq__(self, other):
-        return (isinstance(other, self.__class__) and
-                self.data.equals(other.data))
+        return isinstance(other, self.__class__) and self.data.equals(other.data)
 
     def __len__(self):
         return len(self.data)
@@ -141,29 +146,31 @@ class GenomicArray(object):
             # A single row
             return self.data.iloc[index]
             # return self.as_dataframe(self.data.iloc[index:index+1])
-        elif isinstance(index, str):
+        if isinstance(index, str):
             # A column, by name
             return self.data[index]
-        elif (isinstance(index, tuple) and
-              len(index) == 2 and
-              index[1] in self.data.columns):
+        if (
+            isinstance(index, tuple)
+            and len(index) == 2
+            and index[1] in self.data.columns
+        ):
             # Row index, column index -> cell value
             return self.data.loc[index]
-        elif isinstance(index, slice):
+        if isinstance(index, slice):
             # return self.as_dataframe(self.data.take(index))
             return self.as_dataframe(self.data[index])
-        else:
-            # Iterable -- selected row indices or boolean array, probably
-            try:
-                if isinstance(index, type(None)) or len(index) == 0:
-                    empty = pd.DataFrame(columns=self.data.columns)
-                    return self.as_dataframe(empty)
-            except TypeError:
-                raise TypeError("object of type %r " % type(index) +
-                                "cannot be used as an index into a " +
-                                self.__class__.__name__)
-            return self.as_dataframe(self.data[index])
-            # return self.as_dataframe(self.data.take(index))
+        # Iterable -- selected row indices or boolean array, probably
+        try:
+            if isinstance(index, type(None)) or len(index) == 0:
+                empty = pd.DataFrame(columns=self.data.columns)
+                return self.as_dataframe(empty)
+        except TypeError as exc:
+            raise TypeError(
+                f"object of type {type(index)!r} "
+                f"cannot be used as an index into a {self.__class__.__name__}"
+            ) from exc
+        return self.as_dataframe(self.data[index])
+        # return self.as_dataframe(self.data.take(index))
 
     def __setitem__(self, index, value):
         """Assign to a portion of the data."""
@@ -171,9 +178,11 @@ class GenomicArray(object):
             self.data.iloc[index] = value
         elif isinstance(index, str):
             self.data[index] = value
-        elif (isinstance(index, tuple) and
-              len(index) == 2 and
-              index[1] in self.data.columns):
+        elif (
+            isinstance(index, tuple)
+            and len(index) == 2
+            and index[1] in self.data.columns
+        ):
             self.data.loc[index] = value
         else:
             assert isinstance(index, slice) or len(index) > 0
@@ -189,19 +198,19 @@ class GenomicArray(object):
 
     @property
     def chromosome(self):
-        return self.data['chromosome']
+        return self.data["chromosome"]
 
     @property
     def start(self):
-        return self.data['start']
+        return self.data["start"]
 
     @property
     def end(self):
-        return self.data['end']
+        return self.data["end"]
 
     @property
     def sample_id(self):
-        return self.meta.get('sample_id')
+        return self.meta.get("sample_id")
 
     # Traversal
 
@@ -215,7 +224,7 @@ class GenomicArray(object):
             if isinstance(also, str):
                 also = [also]
             for a_chrom in also:
-                is_auto |= (self.chromosome == a_chrom)
+                is_auto |= self.chromosome == a_chrom
         return self[is_auto]
 
     def by_arm(self, min_gap_size=1e5, min_arm_bins=50):
@@ -226,31 +235,42 @@ class GenomicArray(object):
         # - Cache centromere locations once found
         self.data.chromosome = self.data.chromosome.astype(str)
         for chrom, subtable in self.data.groupby("chromosome", sort=False):
-            margin = max(min_arm_bins, int(round(.1 * len(subtable))))
+            margin = max(min_arm_bins, int(round(0.1 * len(subtable))))
             if len(subtable) > 2 * margin + 1:
                 # Found a candidate centromere
-                gaps = (subtable.start.values[margin+1:-margin] -
-                        subtable.end.values[margin:-margin-1])
+                gaps = (
+                    subtable.start.values[margin + 1 : -margin]
+                    - subtable.end.values[margin : -margin - 1]
+                )
                 cmere_idx = gaps.argmax() + margin + 1
                 cmere_size = gaps[cmere_idx - margin - 1]
             else:
                 cmere_idx = 0
                 cmere_size = 0
             if cmere_idx and cmere_size >= min_gap_size:
-                logging.debug("%s centromere at %d of %d bins (size %s)",
-                             chrom, cmere_idx, len(subtable), cmere_size)
+                logging.debug(
+                    "%s centromere at %d of %d bins (size %s)",
+                    chrom,
+                    cmere_idx,
+                    len(subtable),
+                    cmere_size,
+                )
                 p_arm = subtable.index[:cmere_idx]
-                yield chrom, self.as_dataframe(subtable.loc[p_arm,:])
+                yield chrom, self.as_dataframe(subtable.loc[p_arm, :])
                 q_arm = subtable.index[cmere_idx:]
-                yield chrom, self.as_dataframe(subtable.loc[q_arm,:])
+                yield chrom, self.as_dataframe(subtable.loc[q_arm, :])
             else:
                 # No centromere found -- emit the whole chromosome
                 if cmere_idx:
-                    logging.debug("%s: Ignoring centromere at %d of %d bins (size %s)",
-                                  chrom, cmere_idx, len(subtable), cmere_size)
+                    logging.debug(
+                        "%s: Ignoring centromere at %d of %d bins (size %s)",
+                        chrom,
+                        cmere_idx,
+                        len(subtable),
+                        cmere_size,
+                    )
                 else:
-                    logging.debug("%s: Skipping centromere search, too small",
-                                  chrom)
+                    logging.debug("%s: Skipping centromere search, too small", chrom)
                 yield chrom, self.as_dataframe(subtable)
 
     def by_chromosome(self):
@@ -258,7 +278,7 @@ class GenomicArray(object):
         for chrom, subtable in self.data.groupby("chromosome", sort=False):
             yield chrom, self.as_dataframe(subtable)
 
-    def by_ranges(self, other, mode='outer', keep_empty=True):
+    def by_ranges(self, other, mode="outer", keep_empty=True):
         """Group rows by another GenomicArray's bin coordinate ranges.
 
         For example, this can be used to group SNVs by CNV segments.
@@ -287,8 +307,7 @@ class GenomicArray(object):
         tuple
             (other bin, GenomicArray of overlapping rows in self)
         """
-        for bin_row, subrange in by_ranges(self.data, other.data,
-                                           mode, keep_empty):
+        for bin_row, subrange in by_ranges(self.data, other.data, mode, keep_empty):
             if len(subrange):
                 yield bin_row, self.as_dataframe(subrange)
             elif keep_empty:
@@ -319,7 +338,7 @@ class GenomicArray(object):
     def labels(self):
         return self.data.apply(to_label, axis=1)
 
-    def in_range(self, chrom=None, start=None, end=None, mode='outer'):
+    def in_range(self, chrom=None, start=None, end=None, mode="outer"):
         """Get the GenomicArray portion within the given genomic range.
 
         Parameters
@@ -351,7 +370,7 @@ class GenomicArray(object):
         results = iter_ranges(self.data, chrom, start, end, mode)
         return self.as_dataframe(next(results))
 
-    def in_ranges(self, chrom=None, starts=None, ends=None, mode='outer'):
+    def in_ranges(self, chrom=None, starts=None, ends=None, mode="outer"):
         """Get the GenomicArray portion within the specified ranges.
 
         Similar to `in_ranges`, but concatenating the selections of all the
@@ -381,8 +400,7 @@ class GenomicArray(object):
             Concatenation of all the subsets of `self` enclosed by the specified
             ranges.
         """
-        table = pd.concat(iter_ranges(self.data, chrom, starts, ends, mode),
-                          sort=False)
+        table = pd.concat(iter_ranges(self.data, chrom, starts, ends, mode), sort=False)
         return self.as_dataframe(table)
 
     def into_ranges(self, other, column, default, summary_func=None):
@@ -428,12 +446,11 @@ class GenomicArray(object):
             other's genomic ranges, the same length as `other`.
         """
         if column not in self:
-            logging.warning("No '%s' column available for summary calculation",
-                            column)
+            logging.warning("No '%s' column available for summary calculation", column)
             return pd.Series(np.repeat(default, len(other)))
         return into_ranges(self.data, other.data, column, default, summary_func)
 
-    def iter_ranges_of(self, other, column, mode='outer', keep_empty=True):
+    def iter_ranges_of(self, other, column, mode="outer", keep_empty=True):
         """Group rows by another GenomicArray's bin coordinate ranges.
 
         For example, this can be used to group SNVs by CNV segments.
@@ -465,7 +482,7 @@ class GenomicArray(object):
             (other bin, GenomicArray of overlapping rows in self)
         """
         if column not in self.data.columns:
-            raise ValueError("No column named %r in this object" % column)
+            raise ValueError(f"No column named {column!r} in this object")
         ser = self.data[column]
         for slc in iter_slices(self.data, other.data, mode, keep_empty):
             yield ser[slc]
@@ -478,10 +495,11 @@ class GenomicArray(object):
         Any optional columns must match between both arrays.
         """
         if not isinstance(other, self.__class__):
-            raise ValueError("Argument (type %s) is not a %s instance"
-                             % (type(other), self.__class__))
+            raise ValueError(
+                f"Argument (type {type(other)}) is not a {self.__class__} instance"
+            )
         if len(other.data):
-            self.data = self.data.append(other.data, ignore_index=True)
+            self.data = pd.concat([self.data, other.data], ignore_index=True)
             self.sort()
 
     def concat(self, others):
@@ -571,11 +589,12 @@ class GenomicArray(object):
     def sort(self):
         """Sort this array's bins in-place, with smart chromosome ordering."""
         sort_key = self.data.chromosome.apply(sorter_chrom)
-        self.data = (self.data.assign(_sort_key_=sort_key)
-                     .sort_values(by=['_sort_key_', 'start', 'end'],
-                                  kind='mergesort')
-                     .drop('_sort_key_', axis=1)
-                     .reset_index(drop=True))
+        self.data = (
+            self.data.assign(_sort_key_=sort_key)
+            .sort_values(by=["_sort_key_", "start", "end"], kind="mergesort")
+            .drop("_sort_key_", axis=1)
+            .reset_index(drop=True)
+        )
 
     def sort_columns(self):
         """Sort this array's columns in-place, per class definition."""
@@ -596,25 +615,28 @@ class GenomicArray(object):
 
     def flatten(self, combine=None, split_columns=None):
         """Split this array's regions where they overlap."""
-        return self.as_dataframe(flatten(self.data, combine=combine,
-                                         split_columns=split_columns))
+        return self.as_dataframe(
+            flatten(self.data, combine=combine, split_columns=split_columns)
+        )
 
-    def intersection(self, other, mode='outer'):
+    def intersection(self, other, mode="outer"):
         """Select the bins in `self` that overlap the regions in `other`.
 
         The extra fields of `self`, but not `other`, are retained in the output.
         """
         # TODO options for which extra fields to keep
         #   by default, keep just the fields in 'table'
-        if mode == 'trim':
+        if mode == "trim":
             # Slower
-            chunks = [chunk.data for _, chunk in
-                      self.by_ranges(other, mode=mode, keep_empty=False)]
+            chunks = [
+                chunk.data
+                for _, chunk in self.by_ranges(other, mode=mode, keep_empty=False)
+            ]
             return self.as_dataframe(pd.concat(chunks))
-        else:
-            slices = iter_slices(self.data, other.data, mode, False)
-            indices = np.concatenate(list(slices))
-            return self.as_dataframe(self.data.loc[indices])
+        # Faster
+        slices = iter_slices(self.data, other.data, mode, False)
+        indices = np.concatenate(list(slices))
+        return self.as_dataframe(self.data.loc[indices])
 
     def merge(self, bp=0, stranded=False, combine=None):
         """Merge adjacent or overlapping regions into single rows.
@@ -642,14 +664,16 @@ class GenomicArray(object):
             in `self` must be included.
         """
         table = self.data
-        limits = dict(lower=0)
+        limits = {"lower": 0}
         if chrom_sizes:
-            limits['upper'] = self.chromosome.replace(chrom_sizes)
-        table = table.assign(start=(table['start'] - bp).clip(**limits),
-                             end=(table['end'] + bp).clip(**limits))
+            limits["upper"] = self.chromosome.replace(chrom_sizes)
+        table = table.assign(
+            start=(table["start"] - bp).clip(**limits),
+            end=(table["end"] + bp).clip(**limits),
+        )
         if bp < 0:
             # Drop any bins that now have zero or negative size
-            ok_size = table['end'] - table['start'] > 0
+            ok_size = table["end"] - table["start"] > 0
             logging.debug("Dropping %d bins with size <= 0", (~ok_size).sum())
             table = table[ok_size]
         # Don't modify the original
@@ -662,8 +686,7 @@ class GenomicArray(object):
 
     def subdivide(self, avg_size, min_size=0, verbose=False):
         """Split this array's regions into roughly equal-sized sub-regions."""
-        return self.as_dataframe(subdivide(self.data, avg_size, min_size,
-                                           verbose))
+        return self.as_dataframe(subdivide(self.data, avg_size, min_size, verbose))
 
     def subtract(self, other):
         """Remove the overlapping regions in `other` from this array."""
@@ -685,14 +708,14 @@ class GenomicArray(object):
             An (ordered) dictionary of unique gene names and the data indices of
             their segments in the order of occurrence (genomic order).
         """
-        if 'gene' not in self.data:
+        if "gene" not in self.data:
             return OrderedDict()
 
         genes = OrderedDict()
-        for idx, genestr in self.data['gene'].iteritems():
+        for idx, genestr in self.data["gene"].items():
             if pd.isnull(genestr):
                 continue
-            for gene in genestr.split(','):
+            for gene in genestr.split(","):
                 if gene not in genes:
                     genes[gene] = []
                 genes[gene].append(idx)
