@@ -14,9 +14,10 @@ from .merge import merge
 
 
 def subdivide(table, avg_size, min_size=0, verbose=False):
+    """Split `table` rows into sub-regions of about `avg_size`."""
     return pd.DataFrame.from_records(
-        _split_targets(table, avg_size, min_size, verbose),
-        columns=table.columns)
+        _split_targets(table, avg_size, min_size, verbose), columns=table.columns
+    )
 
 
 def _split_targets(regions, avg_size, min_size, verbose):
@@ -29,8 +30,8 @@ def _split_targets(regions, avg_size, min_size, verbose):
     avg_size : int
         Split regions into equal-sized subregions of about this size.
         Specifically, subregions are no larger than 150% of this size, no
-        smaller than 75% this size, and the average will approach this size when
-        subdividing a large region.
+        smaller than 75% this size, and the average will approach this size
+        when subdividing a large region.
     min_size : int
         Drop any regions smaller than this size.
     verbose : bool
@@ -48,10 +49,16 @@ def _split_targets(regions, avg_size, min_size, verbose):
                 bin_size = span / nbins
                 bin_start = row.start
                 if verbose:
-                    label = (row.gene if 'gene' in regions else
-                             "%s:%d-%d" % (row.chromosome, row.start, row.end))
-                    logging.info("Splitting: {:30} {:7} / {} = {:.2f}"
-                                 .format(label, span, nbins, bin_size))
+                    label = (
+                        row.gene
+                        if "gene" in regions
+                        else f"{row.chromosome}:{row.start}-{row.end}"
+                    )
+                    logging.info(
+                        "Splitting: {:30} {:7} / {} = {:.2f}".format(
+                            label, span, nbins, bin_size
+                        )
+                    )
                 for i in range(1, nbins):
                     bin_end = row.start + int(i * bin_size)
                     yield row._replace(start=bin_start, end=bin_end)
