@@ -13,9 +13,13 @@ from Bio.File import as_handle
 
 
 def read_dict(infile):
-    colnames = ["chromosome", "start", "end", # "file", "md5"
-               ]
-    with as_handle(infile, 'r') as handle:
+    colnames = [
+        "chromosome",
+        "start",
+        "end",
+        # "file", "md5"
+    ]
+    with as_handle(infile, "r") as handle:
         rows = _parse_lines(handle)
         return pd.DataFrame.from_records(rows, columns=colnames)
 
@@ -29,12 +33,13 @@ def _parse_lines(lines):
                 length = int(ln[3:])
                 yield (chrom, 0, length)
             else:
-                raise ValueError("Bad line: %r" % line)
+                raise ValueError(f"Bad line: {line!r}")
         elif line.startswith("@HD"):
             pass
         else:
             # NB: not sure if there's any other valid row type
             # Assume it's some garbage at the end of the file & bail
-            # (or an interval list with SAM header, but we've specified dict and
-            #  not interval, so still return what we've parsed up to this point)
+            # (or an interval list with SAM header, but we've specified dict
+            # and not interval, so still return what we've parsed up to this
+            # point)
             break
