@@ -7,6 +7,7 @@ def report_bad_line(line_parser):
     def wrapper(line):
         try:
             return line_parser(line)
-        except ValueError:
-            raise ValueError("Bad line: %r" % line)
+        except ValueError as exc:
+            raise ValueError("Bad line: %r" % line) from exc
+
     return wrapper
